@@ -1,11 +1,9 @@
-import os
-
-import dotenv
 import fire
 from slack_sdk import WebClient
 from slck.channel import ChannelManager
 from slck.message import MessageManager
 from slck.user import UserManager
+from slck.utils import get_token
 
 
 class SlackManager:
@@ -16,12 +14,6 @@ class SlackManager:
         self.message = MessageManager(self.__client)
 
 
-def get_token() -> str:
-    dotenv.load_dotenv()
-    token: str = os.environ["SLACK_BOT_TOKEN"]
-    return token
-
-
 def main() -> None:
     token: str = get_token()
     client: WebClient = WebClient(token)
