@@ -1,8 +1,21 @@
+import os
 import sys
-from typing import Dict
+from typing import Dict, Optional
+
+import dotenv
 
 
-def confirm_user_input(question: str, default: str = "yes") -> bool:
+def get_token() -> str:
+    dotenv.load_dotenv(override=True)
+    token: Optional[str] = os.getenv("SLACK_BOT_TOKEN")
+    if token is None:
+        raise KeyError("SLACK_BOT_TOKEN is not found.")
+    return token
+
+
+def confirm_user_input(
+    question: str, default: str = "yes", answer: Optional[str] = None
+) -> bool:
     """Ask a yes/no question via raw_input() and return their answer.
 
     "question" is a string that is presented to the user.
@@ -29,10 +42,10 @@ def confirm_user_input(question: str, default: str = "yes") -> bool:
 
     while True:
         sys.stdout.write(question + prompt)
-        choice: str = input().lower()
+        choice: str = input().lower() if answer is None else answer
         if choice == "":
             return valid[default]
         elif choice in valid:
             return valid[choice]
         else:
-            sys.stdout.write("Please respond with 'yes' or 'no' " "(or 'y' or 'n').\n")
\ No newline at end of file
+            sys.stdout.write("Please respond with 'yes' or 'no' " "(or 'y' or 'n').\n")
